@@ -4,7 +4,7 @@
 
 ./configure \
   $PKGCFG \
-  $CROSSCFG \
+  --host=i686-w64-mingw32.static \
   --without-asciidoc \
   --with-ptw32=$PREFIX/i686-w64-mingw32.static \
   --with-libiconv-prefix=$PREFIX/iconv \
@@ -13,7 +13,7 @@
   PTW32_LIBS="-lpthread -lpcreposix -lpcre" \
   FLTK_CONFIG=$PREFIX/bin/i686-w64-mingw32.static-fltk-config \
 
-make -j 8
+make -j 4
 
 $PREFIX/bin/i686-w64-mingw32.static-strip src/fldigi.exe
 $PREFIX/bin/i686-w64-mingw32.static-strip src/flarq.exe
