@@ -4,7 +4,7 @@
 
 r=0
 for f in $fldigi_SOURCES $flarq_SOURCES; do
-    base=$(echo $f | sed -n '/\.[cC][cCpPxX]\{1,\}/ { s!.*/\(.*\)\.[^.]*$!\1!; p }')
+    base=$(echo $f | sed -n '/\.[cC][cCpPxX]\{1,\}/ { s!.*/\(.*\)\.[^.]*$!\1!p; }')
     test "x$base" = "x" && continue
     test -f "fldigi-${base}.${OBJEXT}" || test -f "flarq-${base}.${OBJEXT}" || continue
     if ! grep "include.*config\.h" "${srcdir}/${f}" >/dev/null; then
