@@ -54,6 +54,8 @@
 
 #include <FL/Fl_Progress.H>
 
+#define UI_debug
+
 extern fre_t seek_re;
 
 extern Fl_Double_Window *fl_digi_main;
@@ -72,6 +74,7 @@ extern Fl_Double_Window *dxcc_window;
 extern Fl_Double_Window	*dxcluster_viewer;
 extern Fl_Double_Window *rxaudio_dialog;
 extern Fl_Double_Window *cwsettings;
+extern Fl_Double_Window *dlgGPIO_config;
 
 extern Fl_Menu_Item 	menu_[];
 extern int 				main_menu_size;
@@ -340,9 +343,11 @@ extern Fl_Light_Button		*btnTxRSID;
 extern Fl_Light_Button		*btnTune;
 extern Fl_Light_Button		*btnAutoSpot;
 
-extern bool			bWF_only;
+extern bool				bWF_only;
 extern int				altMacros;
 
+extern bool				ui_debug;
+
 extern waterfall		*wf;
 extern Digiscope		*digiscope;
 
@@ -373,7 +378,9 @@ extern void activate_thor_image_item(bool b);
 extern void WF_UI();
 
 extern void set_macroLabels();
-extern void UI_select();
+
+extern void UI_select(std::string parent = "");
+extern void UI_STATS(std::string parent = "");
 
 extern void cb_mnuVisitURL(Fl_Widget*, void* arg);
 
@@ -447,6 +454,32 @@ extern void set_default_btn_color();
 
 extern void put_WARNstatus(double);
 
+extern Fl_Group *wfgp1;
+extern Fl_Group *wfgp2;
+extern Fl_Group *wfgp3;
+extern Fl_Group *wfgp4;
+extern Fl_Group *wfgp5;
+extern Fl_Group *wfgp6;
+extern Fl_Group *wfgp7;
+extern Fl_Group *wfgp8;
+extern Fl_Group *wfgp9;
+extern Fl_Group *wfgp10;
+extern Fl_Group *wfgp11;
+extern Fl_Group *wfgp12;
+
+extern Fl_Box *wfbx1;
+extern Fl_Box *wfbx2;
+extern Fl_Box *wfbx3;
+extern Fl_Box *wfbx4;
+extern Fl_Box *wfbx5;
+extern Fl_Box *wfbx6;
+extern Fl_Box *wfbx7;
+extern Fl_Box *wfbx8;
+extern Fl_Box *wfbx9;
+extern Fl_Box *wfbx10;
+extern Fl_Box *wfbx11;
+extern Fl_Box *wfbx12;
+
 extern void qsoSave_cb(Fl_Widget *b, void *);
 
 extern bool que_ok;
@@ -566,6 +599,7 @@ extern const char* ltime(void);
 extern const double zusec(void);
 extern const timeval tmval(void);
 extern const unsigned long zmsec(void);
+extern const unsigned long secs(void);
 extern void  start_macro_time();
 extern int   stop_macro_time();
 
@@ -779,14 +813,12 @@ extern Fl_Counter2			*cntcwsrange;
 extern Fl_Check_Button		*btncwsuseSOMdecoding;
 extern Fl_Check_Button		*btncwsmfilt;
 extern Fl_Counter2			*cntcwsbandwidth;
-extern Fl_Choice			*mnu_cws_fillen;
 
 extern void cb_btncwsrcvTrack(Fl_Check_Button*, void*);
 extern void cb_cntcwsrange(Fl_Counter2*, void*);
 extern void cb_btncwsuseSOMdecoding(Fl_Check_Button*, void*);
 extern void cb_btncwsmfilt(Fl_Check_Button*, void*);
 extern void cb_cntcwsbandwidth(Fl_Counter2*, void*);
-extern void cb_mnu_cws_fillen(Fl_Choice*, void*);
 
 extern Fl_Double_Window *nano_calibration_dialog();;
 
