@@ -23,6 +23,8 @@
 
 #include <FL/Fl_Input.H>
 
+#include "config.h"
+
 class Fl_Input2 : public Fl_Input
 {
 private:
@@ -35,6 +37,13 @@ private:
 public:
 	Fl_Input2(int x, int y, int w, int h, const char* l = 0);
 	int handle(int event);
+
+#if FLDIGI_FLTK_API_MINOR > 3
+	int position() { return Fl_Input::insert_position(); }
+	int position(int p, int m) { return Fl_Input::insert_position(p, m); }
+	int position(int p) { return Fl_Input::insert_position(p, p); }
+#endif
+
 };
 
 #endif // FL_INPUT2_
