@@ -86,15 +86,71 @@ inline double rcos( double t, double T, double alpha=1.0 )
     return (sin(M_PI*t/T)/(M_PI*t/T))*cos(alpha*M_PI*t/T)/(1.0-(t/taT)*(t/taT));
 }
 
+// ----------------------------------------------------------------------------
+
 // Rectangular - no pre filtering of data array
-void RectWindow(double *array, int n);
+template <class X>
+void RectWindow(X *array, int n) {
+	for (int i = 0; i < n; i++)
+		array[i] = 1.0;
+}
+
 // Hamming - used by gmfsk
-void HammingWindow(double *array, int n);
+template <class X>
+void HammingWindow(X *array, int n) {
+	double pwr = 0.0;
+	double inv_n = 1.0 / (double)n;
+	for (int i = 0; i < n; i++) {
+		array[i] = hamming((double)i * inv_n);
+		pwr += array[i] * array[i];
+	}
+	pwr = sqrt((double)n/pwr);
+	for (int i = 0; i < n; i++)
+		array[i] *= pwr;
+}
+
 // Hanning - used by winpsk
-void HanningWindow(double *array, int n);
+template <class X>
+void HanningWindow(X *array, int n) {
+	double pwr = 0.0;
+	double inv_n = 1.0 / (double)n;
+	for (int i = 0; i < n; i++) {
+		array[i] = hanning((double)i * inv_n);
+		pwr += array[i] * array[i];
+	}
+	pwr = sqrt((double)n/pwr);
+	for (int i = 0; i < n; i++)
+		array[i] *= pwr;
+}
+
 // Best lob suppression - least in band ripple
-void BlackmanWindow(double *array, int n);
+template <class X>
+void BlackmanWindow(X *array, int n) {
+	double pwr = 0.0;
+	double inv_n = 1.0 / (double)n;
+	for (int i = 0; i < n; i++) {
+		array[i] = blackman((double)i * inv_n);
+		pwr += array[i] * array[i];
+	}
+	pwr = sqrt((double)n/pwr);
+	for (int i = 0; i < n; i++)
+		array[i] *= pwr;
+}
+
 // Simple about effective as Hamming or Hanning
-void TriangularWindow(double *array, int n);
+template <class X>
+void TriangularWindow(X *array, int n) {
+	double pwr = 0.0;
+	for (int i = 0; i < n; i++) array[i] = 1.0;
+	double inv_n = 1.0 / (double)n;
+	for (int i = 0; i < n / 4; i++) {
+		array[i] = 4.0 * (double)i * inv_n ;
+		array[n-i] = array[i];
+	}
+	for (int i = 0; i < n; i++)	pwr += array[i] * array[i];
+	pwr = sqrt((double)n/pwr);
+	for (int i = 0; i < n; i++)
+		array[i] *= pwr;
+}
 
 #endif
