@@ -249,6 +249,10 @@ private:
 	double rtty_now();
 	int rtty_sleep (double);
 
+	inline void wait_one_byte( double baud, double stopbits) {
+		rtty_sleep( (6.0 + stopbits) / baud + 0.005);
+	}
+
 public:
 	rtty(trx_mode mode);
 	~rtty();
