@@ -126,7 +126,7 @@ public:
 	~throb();
 	void	init();
 	void	rx_init();
-	void	tx_init(SoundBase *sc);
+	void	tx_init();
 	void 	restart() {};
 	int		rx_process(const double *buf, int len);
 	int		tx_process();
