@@ -411,17 +411,29 @@ void QRZ_disp_result()
 	}
 
 	inpQth->value(lookup_qth.c_str());
+#if FLDIGI_FLTK_API_MINOR < 4
 	inpQth->position (0);
-
+#else
+	inpQth->insert_position (0);
+#endif
 	inpState->value(lookup_state.c_str());
+#if FLDIGI_FLTK_API_MINOR < 4
 	inpState->position (0);
-
+#else
+	inpState->insert_position (0);
+#endif
 	inpVEprov->value(lookup_province.c_str());
+#if FLDIGI_FLTK_API_MINOR < 4
 	inpVEprov->position (0);
-
+#else
+	inpVEprov->insert_position (0);
+#endif
 	inpLoc->value(lookup_grid.c_str());
+#if FLDIGI_FLTK_API_MINOR < 4
 	inpLoc->position (0);
-
+#else
+	inpLoc->insert_position (0);
+#endif
 	if (!lookup_country.empty()) {
 		cboCountry->value(lookup_country.c_str());
 	}
@@ -435,10 +447,18 @@ void QRZ_disp_result()
 		    QRB::qrb(lon[0], lat[0], lon[1], lat[1], &distance, &azimuth) == QRB::QRB_OK)
 			snprintf(buf, sizeof(buf), "%03.0f", round(azimuth));
 		inpAZ->value(buf);
+#if FLDIGI_FLTK_API_MINOR < 4
 		inpAZ->position (0);
+#else
+		inpAZ->insert_position (0);
+#endif
 	}
 	inpNotes->value(lookup_notes.c_str());
+#if FLDIGI_FLTK_API_MINOR < 4
 	inpNotes->position (0);
+#else
+	inpNotes->insert_position (0);
+#endif
 
 }
 
@@ -707,9 +727,7 @@ void parse_callook(std::string& xmlpage)
 bool CALLOOKGetXML(std::string& xmlpage)
 {
 	std::string url = progdefaults.callookurl;
-	size_t p = 0;
-	if ((p = url.find("https")) != std::string::npos)
-		url.erase(p+4,1);
+
 	url.append(callsign).append("/xml");
 	bool res = get_http(url, xmlpage, 5.0);
 	LOG_VERBOSE("result = %d", res);
