@@ -801,15 +801,18 @@ void mfsk::afc()
 		sigsearch = 0;
 	}
 
-	if (staticburst || !progStatus.afconoff)
-		return;
-	if (metric < progStatus.sldrSquelchValue)
-		return;
 	if (afcmetric < 3.0)
 		return;
+
+	if (metric < progStatus.sldrSquelchValue)
+		return;
+
 	if (currsymbol != prev1symbol)
 		return;
 
+	if (staticburst || !progStatus.afconoff)
+		return;
+
 	if (pipeptr == 0)
 		prevvector = pipe[2*symlen - 1].vector[currsymbol];
 	else
@@ -821,7 +824,7 @@ void mfsk::afc()
 	f1 = tonespacing * (basetone + currsymbol);
 
 	if ( fabs(f1 - f) < ts) {
-		freqerr = decayavg(freqerr, (f1 - f), 32);
+		freqerr = decayavg(freqerr, (f1 - f), progdefaults.mfsk_avg);
 		set_freq(frequency - freqerr);
 	}
 
@@ -1101,19 +1104,14 @@ int mfsk::tx_process()
 	switch (txstate) {
 		case TX_STATE_PREAMBLE:
 			clearbits();
-			sig_start = true;
-//
-// disable silent period
-// QRP Labs qmx series transceiver drops carrier during silent period!
-//
-//			if (mode != MODE_MFSK64L && mode != MODE_MFSK128L )
-//				for (int i = 0; i < preamble / 3; i++)
-//					sendbit(0);
+			if (progdefaults.softMFSK) sig_start = true;
 
+		if (mode != MODE_MFSK64L && mode != MODE_MFSK128L )
+				for (int i = 0; i < preamble / 3; i++)
+					sendbit(0);
 			txstate = TX_STATE_START;
 			break;
 		case TX_STATE_START:
-			sig_start = true;
 			sendchar('\r');
 			sendchar(2);		// STX
 			sendchar('\r');
@@ -1152,11 +1150,17 @@ int mfsk::tx_process()
 		case TX_STATE_FLUSH:
 			sendchar('\r');
 			sendchar(4);		// EOT
-			sig_stop = true;
 			sendchar('\r');
 			flushtx(preamble);
 			rxstate = RX_STATE_DATA;
 			txstate = TX_STATE_PREAMBLE;
+
+			if (progdefaults.softMFSK) sig_stop = true;
+			for (int n = 0; n < (samplerate * progdefaults.SoftStart / 1000 / symlen) + 1; n++) {
+				sendbit(0);
+				sendbit(0);
+			}
+
 			stopflag = false;
 			return -1;
 
